/*
 *   Copyright (c) 2017, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 *   WSO2 Inc. licenses this file to you under the Apache License,
 *   Version 2.0 (the "License"); you may not use this file except
 *   in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing,
 *   software distributed under the License is distributed on an
 *   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *   KIND, either express or implied.  See the License for the
 *   specific language governing permissions and limitations
 *   under the License.
 *
 */

package org.wso2.carbon.device.mgt.api.dto;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModelProperty;

import java.util.ArrayList;
import java.util.List;

import java.util.Objects;

/**
 * ErrorResponse class.
 */
public class ErrorResponse {
    @JsonProperty("code")
    private Integer code = null;

    @JsonProperty("message")
    private String message = null;

    @JsonProperty("description")
    private String description = null;

    @JsonProperty("moreInfo")
    private String moreInfo = null;

    @JsonProperty("errorItems")
    private List<ErrorListItem> errorItems = new ArrayList<ErrorListItem>();

    public ErrorResponse code(Integer code) {
        this.code = code;
        return this;
    }

    /**
     * Get code.
     *
     * @return code
     **/
    @ApiModelProperty(required = true, value = "")
    public Integer getCode() {
        return code;
    }

    public void setCode(Integer code) {
        this.code = code;
    }

    public ErrorResponse message(String message) {
        this.message = message;
        return this;
    }

    /**
     * Error message.
     *
     * @return message
     **/
    @ApiModelProperty(required = true, value = "Error message.")
    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public ErrorResponse description(String description) {
        this.description = description;
        return this;
    }

    /**
     * A detail description about the error message.
     *
     * @return description
     **/
    @ApiModelProperty(value = "A detail description about the error message. ")
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public ErrorResponse moreInfo(String moreInfo) {
        this.moreInfo = moreInfo;
        return this;
    }

    /**
     * Preferably an url with more details about the error.
     *
     * @return moreInfo
     **/
    @ApiModelProperty(value = "Preferably an url with more details about the error. ")
    public String getMoreInfo() {
        return moreInfo;
    }

    public void setMoreInfo(String moreInfo) {
        this.moreInfo = moreInfo;
    }

    public ErrorResponse errorItems(List<ErrorListItem> errorItems) {
        this.errorItems = errorItems;
        return this;
    }

    public ErrorResponse addErrorItemsItem(ErrorListItem errorItemsItem) {
        this.errorItems.add(errorItemsItem);
        return this;
    }

    /**
     * If there are more than one error list them out. For example, list out validation errors by each field.
     *
     * @return errorItems
     **/
    @ApiModelProperty(value = "If there are more than one error list them out. For example, " +
            "list out validation errors by each field. ")
    public List<ErrorListItem> getErrorItems() {
        return errorItems;
    }

    public void setErrorItems(List<ErrorListItem> errorItems) {
        this.errorItems = errorItems;
    }


    @Override
    public boolean equals(java.lang.Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ErrorResponse errorResponse = (ErrorResponse) o;
        return Objects.equals(this.code, errorResponse.code) &&
                Objects.equals(this.message, errorResponse.message) &&
                Objects.equals(this.description, errorResponse.description) &&
                Objects.equals(this.moreInfo, errorResponse.moreInfo) &&
                Objects.equals(this.errorItems, errorResponse.errorItems);
    }

    @Override
    public int hashCode() {
        return Objects.hash(code, message, description, moreInfo, errorItems);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ErrorResponse {\n");

        sb.append("    code: ").append(toIndentedString(code)).append("\n");
        sb.append("    message: ").append(toIndentedString(message)).append("\n");
        sb.append("    description: ").append(toIndentedString(description)).append("\n");
        sb.append("    moreInfo: ").append(toIndentedString(moreInfo)).append("\n");
        sb.append("    errorItems: ").append(toIndentedString(errorItems)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces.
     * (except the first line).
     */
    private String toIndentedString(java.lang.Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }
}

