-- -----------------------------------------------------
-- Table `DM_APPLICATION`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_APPLICATION` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `NAME` VARCHAR(150) NOT NULL,
  `APP_IDENTIFIER` VARCHAR(150) NOT NULL,
  `PLATFORM` VARCHAR(50) NULL DEFAULT NULL,
  `CATEGORY` VARCHAR(50) NULL DEFAULT NULL,
  `VERSION` VARCHAR(50) NULL DEFAULT NULL,
  `TYPE` VARCHAR(50) NULL DEFAULT NULL,
  `LOCATION_URL` VARCHAR(100) NULL DEFAULT NULL,
  `IMAGE_URL` VARCHAR(100) NULL DEFAULT NULL,
  `APP_PROPERTIES` BLOB NULL DEFAULT NULL,
  `MEMORY_USAGE` INT(10) NULL DEFAULT NULL,
  `IS_ACTIVE` TINYINT(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`ID`));


-- -----------------------------------------------------
-- Table `DM_DEVICE_TYPE`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_DEVICE_TYPE` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `NAME` VARCHAR(300) NULL DEFAULT NULL,
  `DEVICE_TYPE_META` TEXT NULL DEFAULT NULL,
  `LAST_UPDATED_TIMESTAMP` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`));


-- -----------------------------------------------------
-- Table `DM_DEVICE`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_DEVICE` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `DESCRIPTION` TEXT NULL DEFAULT NULL,
  `NAME` VARCHAR(100) NULL DEFAULT NULL,
  `DEVICE_TYPE_ID` INT(11) NULL DEFAULT NULL,
  `DEVICE_IDENTIFICATION` VARCHAR(300) NULL DEFAULT NULL,
  `LAST_UPDATED_TIMESTAMP` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `CURRENT_OWNER` VARCHAR(200) NULL DEFAULT NULL,
  PRIMARY KEY (`ID`),
  UNIQUE INDEX `uk_DM_DEVICE` (`NAME` ASC, `DEVICE_TYPE_ID` ASC, `DEVICE_IDENTIFICATION` ASC),
  INDEX `fk_DM_DEVICE_DM_DEVICE_TYPE2` (`DEVICE_TYPE_ID` ASC),
  CONSTRAINT `fk_DM_DEVICE_DM_DEVICE_TYPE2`
    FOREIGN KEY (`DEVICE_TYPE_ID`)
    REFERENCES `DM_DEVICE_TYPE` (`ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);


-- -----------------------------------------------------
-- Table `DM_DEVICE_APPLICATION_MAPPING`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_DEVICE_APPLICATION_MAPPING` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `DEVICE_ID` INT(11) NOT NULL,
  `APPLICATION_ID` INT(11) NOT NULL,
  PRIMARY KEY (`ID`),
  INDEX `fk_dm_device` (`DEVICE_ID` ASC),
  INDEX `fk_dm_application` (`APPLICATION_ID` ASC),
  CONSTRAINT `fk_dm_application`
    FOREIGN KEY (`APPLICATION_ID`)
    REFERENCES `DM_APPLICATION` (`ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_dm_device`
    FOREIGN KEY (`DEVICE_ID`)
    REFERENCES `DM_DEVICE` (`ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);


-- -----------------------------------------------------
-- Table `DM_DEVICE_DETAIL`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_DEVICE_DETAIL` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `DEVICE_ID` INT(11) NOT NULL,
  `DEVICE_MODEL` VARCHAR(45) NULL DEFAULT NULL,
  `VENDOR` VARCHAR(45) NULL DEFAULT NULL,
  `OS_VERSION` VARCHAR(45) NULL DEFAULT NULL,
  `OS_BUILD_DATE` VARCHAR(100) NULL DEFAULT NULL,
  `BATTERY_LEVEL` DECIMAL(4,0) NULL DEFAULT NULL,
  `INTERNAL_TOTAL_MEMORY` DECIMAL(30,3) NULL DEFAULT NULL,
  `INTERNAL_AVAILABLE_MEMORY` DECIMAL(30,3) NULL DEFAULT NULL,
  `EXTERNAL_TOTAL_MEMORY` DECIMAL(30,3) NULL DEFAULT NULL,
  `EXTERNAL_AVAILABLE_MEMORY` DECIMAL(30,3) NULL DEFAULT NULL,
  `CONNECTION_TYPE` VARCHAR(50) NULL DEFAULT NULL,
  `SSID` VARCHAR(45) NULL DEFAULT NULL,
  `CPU_USAGE` DECIMAL(5,0) NULL DEFAULT NULL,
  `TOTAL_RAM_MEMORY` DECIMAL(30,3) NULL DEFAULT NULL,
  `AVAILABLE_RAM_MEMORY` DECIMAL(30,3) NULL DEFAULT NULL,
  `PLUGGED_IN` INT(1) NULL DEFAULT NULL,
  `UPDATE_TIMESTAMP` BIGINT(15) NOT NULL,
  PRIMARY KEY (`ID`),
  INDEX `FK_DM_DEVICE_DETAILS_DEVICE` (`DEVICE_ID` ASC),
  CONSTRAINT `FK_DM_DEVICE_DETAILS_DEVICE`
    FOREIGN KEY (`DEVICE_ID`)
    REFERENCES `DM_DEVICE` (`ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);


-- -----------------------------------------------------
-- Table `DM_ENROLMENT`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_ENROLMENT` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `DEVICE_ID` INT(11) NOT NULL,
  `OWNER` VARCHAR(200) NOT NULL,
  `OWNERSHIP` VARCHAR(45) NULL DEFAULT NULL,
  `STATUS` VARCHAR(50) NULL DEFAULT NULL,
  `DATE_OF_ENROLMENT` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `DATE_OF_LAST_UPDATE` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  UNIQUE INDEX `uk_dm_device_enrolment` (`DEVICE_ID` ASC, `OWNER` ASC, `OWNERSHIP` ASC),
  CONSTRAINT `fk_dm_device_enrolment`
    FOREIGN KEY (`DEVICE_ID`)
    REFERENCES `DM_DEVICE` (`ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);


-- -----------------------------------------------------
-- Table `DM_GROUP`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_GROUP` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `GROUP_NAME` VARCHAR(100) NULL DEFAULT NULL,
  `DESCRIPTION` VARCHAR(200) NULL DEFAULT NULL,
  `OWNER` VARCHAR(200) NULL DEFAULT NULL,
  PRIMARY KEY (`ID`));


-- -----------------------------------------------------
-- Table `DM_ENROLEMENT_GROUP_MAP`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_ENROLEMENT_GROUP_MAP` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `ENROLMENT_ID` INT(11) NOT NULL,
  `GROUP_ID` INT(11) NOT NULL,
  PRIMARY KEY (`ID`),
  INDEX `fk_DM_DEVICE_GROUP_MAP_DM_ENROLMENT2` (`ENROLMENT_ID` ASC),
  INDEX `fk_DM_DEVICE_GROUP_MAP_DM_GROUP2` (`GROUP_ID` ASC),
  CONSTRAINT `fk_DM_DEVICE_GROUP_MAP_DM_ENROLMENT2`
    FOREIGN KEY (`ENROLMENT_ID`)
    REFERENCES `DM_ENROLMENT` (`ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_DM_DEVICE_GROUP_MAP_DM_GROUP2`
    FOREIGN KEY (`GROUP_ID`)
    REFERENCES `DM_GROUP` (`ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE);


-- -----------------------------------------------------
-- Table `DM_DEVICE_INFO`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_DEVICE_INFO` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `DEVICE_ID` INT(11) NULL DEFAULT NULL,
  `KEY_FIELD` VARCHAR(45) NULL DEFAULT NULL,
  `VALUE_FIELD` VARCHAR(100) NULL DEFAULT NULL,
  PRIMARY KEY (`ID`),
  INDEX `DM_DEVICE_INFO_DEVICE` (`DEVICE_ID` ASC),
  CONSTRAINT `DM_DEVICE_INFO_DEVICE`
    FOREIGN KEY (`DEVICE_ID`)
    REFERENCES `DM_DEVICE` (`ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);


-- -----------------------------------------------------
-- Table `DM_DEVICE_LOCATION`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_DEVICE_LOCATION` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `DEVICE_ID` INT(11) NULL DEFAULT NULL,
  `LATITUDE` DOUBLE NULL DEFAULT NULL,
  `LONGITUDE` DOUBLE NULL DEFAULT NULL,
  `STREET1` VARCHAR(255) NULL DEFAULT NULL,
  `STREET2` VARCHAR(45) NULL DEFAULT NULL,
  `CITY` VARCHAR(45) NULL DEFAULT NULL,
  `ZIP` VARCHAR(10) NULL DEFAULT NULL,
  `STATE` VARCHAR(45) NULL DEFAULT NULL,
  `COUNTRY` VARCHAR(45) NULL DEFAULT NULL,
  `UPDATE_TIMESTAMP` BIGINT(15) NOT NULL,
  PRIMARY KEY (`ID`),
  INDEX `DM_DEVICE_LOCATION_DEVICE` (`DEVICE_ID` ASC),
  CONSTRAINT `DM_DEVICE_LOCATION_DEVICE`
    FOREIGN KEY (`DEVICE_ID`)
    REFERENCES `DM_DEVICE` (`ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);


-- -----------------------------------------------------
-- Table `DM_OPERATION`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_OPERATION` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `TYPE` VARCHAR(50) NOT NULL,
  `OPERATION_CODE` VARCHAR(50) NOT NULL,
  `INITIATED_BY` VARCHAR(256) NOT NULL,
  `OPERATION_PAYLOAD` TEXT NULL DEFAULT NULL,
  `CREATED_TIMESTAMP` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`));


-- -----------------------------------------------------
-- Table `DM_ENROLMENT_OP_MAPPING`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_ENROLMENT_OP_MAPPING` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `ENROLMENT_ID` INT(11) NOT NULL,
  `OPERATION_ID` INT(11) NOT NULL,
  `STATUS` VARCHAR(50) NULL DEFAULT NULL,
  `PUSH_NOTIFICATION_STATUS` VARCHAR(50) NULL DEFAULT NULL,
  `CREATED_TIMESTAMP` INT(11) NOT NULL,
  `UPDATED_TIMESTAMP` INT(11) NOT NULL,
  PRIMARY KEY (`ID`),
  INDEX `fk_dm_device_operation_mapping_device` (`ENROLMENT_ID` ASC),
  INDEX `fk_dm_device_operation_mapping_operation` (`OPERATION_ID` ASC),
  CONSTRAINT `fk_dm_device_operation_mapping_device`
    FOREIGN KEY (`ENROLMENT_ID`)
    REFERENCES `DM_ENROLMENT` (`ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_dm_device_operation_mapping_operation`
    FOREIGN KEY (`OPERATION_ID`)
    REFERENCES `DM_OPERATION` (`ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);


-- -----------------------------------------------------
-- Table `DM_DEVICE_OPERATION_RESPONSE`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_DEVICE_OPERATION_RESPONSE` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `ENROLMENT_ID` INT(11) NOT NULL,
  `OPERATION_ID` INT(11) NOT NULL,
  `EN_OP_MAP_ID` INT(11) NOT NULL,
  `OPERATION_RESPONSE` LONGBLOB NULL DEFAULT NULL,
  `RECEIVED_TIMESTAMP` TIMESTAMP NULL DEFAULT NULL,
  PRIMARY KEY (`ID`),
  INDEX `fk_dm_device_operation_response_enrollment` (`ENROLMENT_ID` ASC),
  INDEX `fk_dm_device_operation_response_operation` (`OPERATION_ID` ASC),
  INDEX `fk_dm_en_op_map_response` (`EN_OP_MAP_ID` ASC),
  CONSTRAINT `fk_dm_device_operation_response_enrollment`
    FOREIGN KEY (`ENROLMENT_ID`)
    REFERENCES `DM_ENROLMENT` (`ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_dm_device_operation_response_operation`
    FOREIGN KEY (`OPERATION_ID`)
    REFERENCES `DM_OPERATION` (`ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_dm_en_op_map_response`
    FOREIGN KEY (`EN_OP_MAP_ID`)
    REFERENCES `DM_ENROLMENT_OP_MAPPING` (`ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);


-- -----------------------------------------------------
-- Table `DM_GROUP_USER_MAP`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `DM_GROUP_USER_MAP` (
  `ID` INT(11) NOT NULL,
  `GROUP_ID` INT(11) NOT NULL,
  `USER` VARCHAR(200) NOT NULL,
  `PERMISSIONS` TEXT NOT NULL,
  PRIMARY KEY (`ID`),
  INDEX `fk_DM_GROUP_USER_MAP_1_idx` (`GROUP_ID` ASC),
  CONSTRAINT `fk_DM_GROUP_USER_MAP_1`
    FOREIGN KEY (`GROUP_ID`)
    REFERENCES `DM_GROUP` (`ID`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);

